@@ -1,6 +1,6 @@
 #!/bin/bash
 #Authors: Bernd Paysan, Anton Ertl
-#Copyright (C) 2011,2012,2013,2014,2015,2016,2017,2018 Free Software Foundation, Inc.
+#Copyright (C) 2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2023,2024,2025 Free Software Foundation, Inc.
 
 #This file is part of Gforth.
 
@@ -36,7 +36,7 @@ function extra_perms {
 function extra_features {
     for i in $EXTRADIRS
     do
-	test -f $i/AndroidManifest/app && cat $i/AndroidManifest/features
+	test -f $i/AndroidManifest/features && cat $i/AndroidManifest/features
     done
 }
 
@@ -56,10 +56,10 @@ if [ ! -z "$arch" ]
 then
     (cd $SRC; ./autogen.sh) >autogen.log
     echo "Extra builds in$arch"
-    APP_PACKAGE=gnu.gforth
 else
     APP_PACKAGE=gnu.gforth_$machine
 fi
+APP_PACKAGE=gnu.gforth
 
 APP_VERSION=$[$(cat ~/.app-version)+1]
 for i in $arch
@@ -72,11 +72,6 @@ echo $APP_VERSION >~/.app-version
 
 exec 3>&1 1>build.log 2>&1
 
-if [ ! -f local.properties ]
-then
-    android update project -p . -s --target android-28
-fi
-
 #eval $(grep ^sdk.dir= local.properties| sed -e 's/^sdk.dir=/sdk_dir=/g')
 #
 #mkdir -p libs
@@ -90,6 +85,11 @@ GFORTH_VERSION=$($GFORTH_DITC --version 2>&1 | cut -f2 -d' ')
 
 LIBCCNAMED=lib/gforth/current/$machine/libcc-named/.libs
 
+if [ ! -L $TOOLCHAIN/sysroot/usr/include/stb ]
+then
+    ln -fs /usr/include/stb $TOOLCHAIN/sysroot/usr/include/
+fi
+
 if [ ! -f $SRC/configure ]
 then
     (cd $SRC; ./autogen.sh)
@@ -98,11 +98,12 @@ fi
 rm -rf $LIBS
 mkdir -p $LIBS
 
-if [ ! -f $TOOLCHAIN/sysroot/usr/lib/libsoil2.a ]
-then
-    cp $TOOLCHAIN/sysroot/usr/lib/libsoil.so $LIBS
-fi
 cp .libs/libtypeset.so $LIBS
+cp $TOOLCHAIN/sysroot/usr/lib/libopus.so $LIBS
+cp $TOOLCHAIN/sysroot/usr/lib/libwebp.so $LIBS
+cp $TOOLCHAIN/sysroot/usr/lib/libsharpyuv.so $LIBS
+cp $TOOLCHAIN/sysroot/usr/lib/lib{brotlidec,brotlicommon}.so $LIBS
+cp $(find $TOOLCHAIN/$TARGET -name libc++_shared.so) $LIBS
 
 EXTRAS=""
 EXTRADIRS=""
@@ -113,6 +114,7 @@ do
 done
 
 . ./AndroidManifest.xml.in >AndroidManifest.xml
+. ./build.gradle.in >build.gradle
 
 if [ "$1" != "--no-gforthgz" ]
 then
@@ -131,7 +133,6 @@ then
 	if [ "$1" != "--no-config" ]; then make extras || exit 1; fi
 	echo -n " debdist" 1>&3
 	mkdir -p debian/sdcard/gforth/current/doc
-	cp doc/gforth.txt debian/sdcard/gforth/current/doc
 	make setup-debdist || exit 1) || exit 1
     if [ "$1" == "--no-config" ]
     then
@@ -143,6 +144,7 @@ then
     (cd build/debian/sdcard
      mkdir -p gforth/home gforth/site-forth gforth/current/minos2/fonts
      cp /usr/share/fonts/truetype/emoji/fa-merged-900.ttf gforth/current/minos2/fonts
+     #cp `gforth unix/open-url.fs -e '"doc/gforth.txt" fpath file>abspath type bye'` gforth/current/doc
      gforth archive.fs gforth/home/ gforth/site-forth/ $(find gforth/current -type f) $(find gforth/site-forth -type f)) | gzip -9 >res/raw/gforth
     (cd build/debian/sdcard
      rm gforth/$machine/lib*
@@ -175,10 +177,13 @@ do
     shift
 done
 
-for i in $LIBS/*.so
-do
-    echo "strip $i: $(stat --print=%s $i) -> $($TARGET-strip $i && stat --print=%s $i)"
-done
+if [ "$machine" == "arm" ]
+then
+    for i in $LIBS/*.so
+    do
+	echo "strip $i: $(stat --print=%s $i) -> $($TARGET-strip $i && stat --print=%s $i)"
+    done
+fi
 
 #copy resources
 
@@ -188,11 +193,18 @@ do
     test -d $i/src && (cd $i/src; tar cf - .) | (cd src; tar xf -)
 done
 
-echo -n " ant " 1>&3
+echo -n " gradle " 1>&3
 
+#ant build
 #ant debug
-ant release || exit 1
-cp bin/Gforth-release.apk bin/Gforth.apk
-cp bin/Gforth-release.apk bin/Gforth-$(date +%Y%m%d).apk
+#ant release
+#cp bin/Gforth-release.apk bin/Gforth.apk
+#cp bin/Gforth-release.apk bin/Gforth-$(date +%Y%m%d).apk
+
+#gradle build – get gradlew and put the script right here
+./gradlew build
+./gradlew bundle
+cp build/outputs/apk/release/gnu.gforth-release.apk bin/Gforth.apk
+cp build/outputs/apk/release/gnu.gforth-release.apk bin/Gforth-$(date +%Y%m%d).apk
 
 printf '\e[32msuccess!\e[0m\n' 1>&3
